#include <Adafruit_CircuitPlayground.h>
#include <stdlib.h>

#define MAX_SIDES 31
#define WHITE 255, 255, 255
#define BUTTON_PRESS_DELAY 300

const unsigned int sidedness[7] = {2, 4, 6, 8, 10, 12, 20};
const unsigned int sides = 7;

unsigned int idx = 0;
unsigned int currentSidedness = sidedness[idx];
unsigned int currentRoll = 0;

unsigned long lastLeftButtonPress = millis();
unsigned long lastRightButtonPress = millis();

bool updatePixels = true;

void setup() {
  CircuitPlayground.begin();
}

void loop() {
  if (CircuitPlayground.leftButton() &&
      millis() - lastLeftButtonPress > BUTTON_PRESS_DELAY) {
    lastLeftButtonPress = millis();
    idx = (idx + 1) % sides;
    currentSidedness = sidedness[idx];
    updatePixels = true;
  }

  if (CircuitPlayground.rightButton() &&
      millis() - lastRightButtonPress > BUTTON_PRESS_DELAY) {
    lastRightButtonPress = millis();
    currentRoll = randomUpTo(currentSidedness);
    updatePixels = true;
  }

  if (updatePixels) {
    CircuitPlayground.clearPixels();
    setLeftHalf(currentSidedness);
    setRightHalf(currentRoll);
    updatePixels = false;
  }
}

void setLeftHalf(int val) {
  Serial.print("Sidedness is ");
  Serial.println(val);
  
  int mask = 1;
  int neopixelPos = 0;
  for (mask = 1; mask < MAX_SIDES; mask <<= 1) {
    if (mask & val) {
      CircuitPlayground.setPixelColor(neopixelPos, WHITE);
    }
    neopixelPos++;
  }
}

void setRightHalf(int val) {
  Serial.print("Roll is ");
  Serial.println(val);
  
  int mask = 1;
  int neopixelPos = 9;
  for (mask = 1; mask < MAX_SIDES; mask <<= 1) {
    if (mask & val) {
      CircuitPlayground.setPixelColor(neopixelPos, WHITE);
    }
    neopixelPos--;
  }
}

// Return random integer up to and including the max
unsigned int randomUpTo(int max) {
  return rand() % (int)(max) + 1;
}
